Documentation
¶
Index ¶
Constants ¶
const ( ADSB = "adsb" APRS = "aprs" APRS_IS = "aprsis" AX25 = "ax25" LoRa = "lora" MeshCore = "meshcore" Meshtastic = "meshtastic" )
Protocol standard names (as used in this package).
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Packet ¶
type Packet struct {
Time time.Time `json:"time,omitempty"` // Receive time stamp
Protocol string `json:"protocol"` // Protocol name
Radio string `json:"radio"` // Radio name/ID
SNR float64 `json:"snr"` // Signal-to-noise Ratio
RSSI int `json:"rssi"` // Received Signal Strength Indicator
Raw []byte `json:"raw"` // Raw packet
}
Packet represents a raw packet.
type PacketReceiver ¶
type PacketReceiver interface {
radio.Device
// RawPackets starts receiving raw packets.
RawPackets() <-chan *Packet
}
Receiver of packets.
type PacketTransmitter ¶
type StatsReceiver ¶ added in v1.1.1
Directories
¶
| Path | Synopsis |
|---|---|
|
Package aprs implements Automatic Packet Reporting System message parsing.
|
Package aprs implements Automatic Packet Reporting System message parsing. |
|
crypto/jwt
Package jwt implements JSON Web Tokens (JWT) using Meshcore Ed25519 keys
|
Package jwt implements JSON Web Tokens (JWT) using Meshcore Ed25519 keys |
Click to show internal directories.
Click to hide internal directories.